/**************************************************
*
* PilotLight.c:  pilot light is interrupt-driven to provide
*                blinking feedback of software operation
* 
*  At start-up, pilot light will blink version number, then
*  wait one second before starting ongoing 1 Hz blink rate
*
* Source code by DAXaCK Circuits4Tracks 06-11-2020
***************************************************/
#include <xc.h>
#include <pic.h>
#include "PilotLight.h"
#pragma warning disable 751

#define PilotLight		RC3


enum			ePilotMode	{ eNormal, eDigit3, eDigit2, eDigit1, eStartUp };
static char		TimerReloadHi,
				TimerReloadLo,
				PilotLightMode = eStartUp;

/******************* Timer 1 Control Macros ************************
* RELOAD VALUE:
* This timer is used to flash the pilot light at a 1 Hz rate to provide
* a "heartbeat" indication that the software is running
*
* Clock: 4 MHz  Prescalar: 8
* Clock / 4 cycle: 1 us
* Timer increment: 8 us
* Count for 500 ms: -62,500 or 0x0BDC
*
* CONTROL VALUE:
*	T1GINV  = AL       = 0
*	TMR1GE  = Always   = 0
*	T1CKPS  = 1:8      = 11
*	T1OSCEN = Off      = 0
*	T1SYNC  = n/a      = 0
*	TMR1CS  = internal = 0
*	TMR1ON  = On       = 1
*******************************************************************/
#define TIMER_RELOAD		0x0BDC
#define TIMER_RELOAD_HI		( ( TIMER_RELOAD >> 8 ) & 0xFF )
#define TIMER_RELOAD_LO		(  TIMER_RELOAD & 0xFF )
#define TIMER1_CONTROL		0b00110001


void InitializePilotLight( void )
{
	/*** Set Up Oscillator Control **
	* IRCF   = 4 MHz    = 1101
	* SCS    = FOSC     = 00
	*********************************/
	OSCCON =		0b01101000;

	/*********************************
	* Set up Port C: only bit 3 as output
	*********************************/
	PilotLight =	0;						// initial value: off
	TRISC =			0b11110111;				// Port C: only bit 3 output
	T1CON =			TIMER1_CONTROL;			// Set Up Timer 1
	TMR1H =			TIMER_RELOAD_HI;		// Timer 1 reload high register
	TMR1L =			TIMER_RELOAD_LO;		// Timer 1 reload low register
	TMR1IE =		1;						// Enable Timer 1 overflow interrupt
}


__interrupt() void PilotLightBlink( void )
{
	if( TMR1IF )
	{
		// Occurs every 500 ms to generate 1 Hz pilot light blink
		TMR1H = TIMER_RELOAD_HI;			// Reload Timer 1
		TMR1L = TIMER_RELOAD_HI;			// Reload Timer 1
		TMR1IF = 0;							// Clear interrupt
		PilotLight = PilotLight ? 0 : 1;	// just blink the light
	}
}
